==> haskell-crypto-pubkey-types-0.4.3-23-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-crypto-pubkey-types.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: crypto-pubkey-types
version: 0.4.3
id: crypto-pubkey-types-0.4.3-KLrr09Yv9GPCvR6I66k694
key: crypto-pubkey-types-0.4.3-KLrr09Yv9GPCvR6I66k694
license: BSD3
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
homepage: http://github.com/vincenthz/hs-crypto-pubkey-types
synopsis: Generic cryptography Public keys algorithm types
description:
    Generic cryptography public keys algorithm types
category: Cryptography
author: Vincent Hanquez <vincent@snarc.org>
exposed: True
indefinite: False
exposed-modules:
    Crypto.Types.PubKey.DH Crypto.Types.PubKey.DSA
    Crypto.Types.PubKey.ECC Crypto.Types.PubKey.ECDSA
    Crypto.Types.PubKey.RSA
abi: f271f5706173e2c5eceeff710ba3c349
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/crypto-pubkey-types-0.4.3
library-dirs: /usr/lib/ghc-8.2.1/site-local/crypto-pubkey-types-0.4.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.1/crypto-pubkey-types-0.4.3
hs-libraries: HScrypto-pubkey-types-0.4.3-KLrr09Yv9GPCvR6I66k694
depends:
    asn1-encoding-0.9.5-3Bn1hocdFrVJ4IbVdDcoyr
    asn1-types-0.3.2-Cp1wdTJG2wtISDf5jp8dcb base-4.10.0.0
abi-depends: asn1-encoding-0.9.5-3Bn1hocdFrVJ4IbVdDcoyr=8af4fc27d65764603534b50ed2e1f4d8
             asn1-types-0.3.2-Cp1wdTJG2wtISDf5jp8dcb=258a3fd5c56efea77c4f3a1d0a0d1045
             base-4.10.0.0=32d562aa6d04d35ac79a0f49c17325ff
haddock-interfaces: /usr/share/doc/haskell-crypto-pubkey-types/html/crypto-pubkey-types.haddock
haddock-html: /usr/share/doc/haskell-crypto-pubkey-types/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-crypto-pubkey-types-0.4.3-24-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-crypto-pubkey-types.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: crypto-pubkey-types
version: 0.4.3
id: crypto-pubkey-types-0.4.3-AfRRiCZKKND686E9Phqbff
key: crypto-pubkey-types-0.4.3-AfRRiCZKKND686E9Phqbff
license: BSD3
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
homepage: http://github.com/vincenthz/hs-crypto-pubkey-types
synopsis: Generic cryptography Public keys algorithm types
description:
    Generic cryptography public keys algorithm types
category: Cryptography
author: Vincent Hanquez <vincent@snarc.org>
exposed: True
indefinite: False
exposed-modules:
    Crypto.Types.PubKey.DH Crypto.Types.PubKey.DSA
    Crypto.Types.PubKey.ECC Crypto.Types.PubKey.ECDSA
    Crypto.Types.PubKey.RSA
abi: ab088e743496fd800cf86539daeef5d4
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/crypto-pubkey-types-0.4.3
library-dirs: /usr/lib/ghc-8.2.1/site-local/crypto-pubkey-types-0.4.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.1/crypto-pubkey-types-0.4.3
hs-libraries: HScrypto-pubkey-types-0.4.3-AfRRiCZKKND686E9Phqbff
depends:
    asn1-encoding-0.9.5-8mKnGJnlPdN3znZAPxW19G
    asn1-types-0.3.2-48XQGtsS6SE5zfarz06o85 base-4.10.0.0
abi-depends: asn1-encoding-0.9.5-8mKnGJnlPdN3znZAPxW19G=6e181825416b69e608b83d5728cdcc65
             asn1-types-0.3.2-48XQGtsS6SE5zfarz06o85=575f545131a6fdb4df75d03cd7306f6e
             base-4.10.0.0=32d562aa6d04d35ac79a0f49c17325ff
haddock-interfaces: /usr/share/doc/haskell-crypto-pubkey-types/html/crypto-pubkey-types.haddock
haddock-html: /usr/share/doc/haskell-crypto-pubkey-types/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
